@@ -24,6 +24,7 @@
 
 package picard.fingerprint;
 
+import com.google.common.annotations.VisibleForTesting;
 import htsjdk.samtools.SAMSequenceDictionary;
 import htsjdk.samtools.reference.ReferenceSequenceFile;
 import htsjdk.samtools.reference.ReferenceSequenceFileFactory;
@@ -143,7 +144,8 @@ public class FingerprintUtils {
         return variantContexts;
     }
 
-    private static VariantContext getVariantContext(final ReferenceSequenceFile reference,
+    @VisibleForTesting
+    static VariantContext getVariantContext(final ReferenceSequenceFile reference,
                                                     final String sample,
                                                     final HaplotypeProbabilities haplotypeProbabilities) {
         final Snp snp = haplotypeProbabilities.getRepresentativeSnp();
@@ -173,18 +175,19 @@ public class FingerprintUtils {
             obsAlt = haplotypeProbabilities.getObsAllele2();
         }
 
-        final double[] origPLs = haplotypeProbabilities.getLogLikelihoods();
-        final double[] PLs =  Arrays.copyOf(origPLs,origPLs.length);
+        final double[] origGLs = haplotypeProbabilities.getLogLikelihoods();
+        final double[] GLs =  Arrays.copyOf(origGLs, origGLs.length);
+
         if (swap12) {
-            ArrayUtils.reverse(PLs);
+            ArrayUtils.reverse(GLs);
         }
         final List<Allele> alleles = Arrays.asList(alleleRef, alleleAlt);
 
         final Genotype gt = new GenotypeBuilder()
                 .DP(haplotypeProbabilities.getTotalObs())
                 .noAttributes()
-                .PL(PLs)
-                .AD(new int[]{obsAlt, obsRef})
+                .PL(GLs)
+                .AD(new int[]{obsRef, obsAlt})
                 .name(sample)
                 .make();
         try {
