@@ -38,11 +38,12 @@ import htsjdk.samtools.util.ProgressLogger;
 import htsjdk.samtools.util.SequenceUtil;
 import htsjdk.samtools.util.SortingCollection;
 import htsjdk.samtools.util.StringUtil;
+import org.broadinstitute.barclay.argparser.Argument;
+import org.broadinstitute.barclay.argparser.CommandLineProgramProperties;
+import org.broadinstitute.barclay.help.DocumentedFeature;
 import picard.PicardException;
-import picard.cmdline.CommandLineProgramProperties;
-import picard.cmdline.Option;
 import picard.cmdline.StandardOptionDefinitions;
-import picard.cmdline.programgroups.Metrics;
+import picard.cmdline.programgroups.DiagnosticsAndQCProgramGroup;
 import picard.sam.DuplicationMetrics;
 import picard.sam.markduplicates.util.AbstractOpticalDuplicateFinderCommandLineProgram;
 import picard.sam.util.PhysicalLocationShort;
@@ -78,10 +79,11 @@ import static java.lang.Math.pow;
  * @author Tim Fennell
  */
 @CommandLineProgramProperties(
-        usage = EstimateLibraryComplexity.USAGE_SUMMARY + EstimateLibraryComplexity.USAGE_DETAILS,
-        usageShort = EstimateLibraryComplexity.USAGE_SUMMARY,
-        programGroup = Metrics.class
+        summary = EstimateLibraryComplexity.USAGE_SUMMARY + EstimateLibraryComplexity.USAGE_DETAILS,
+        oneLineSummary = EstimateLibraryComplexity.USAGE_SUMMARY,
+        programGroup = DiagnosticsAndQCProgramGroup.class
 )
+@DocumentedFeature
 public class EstimateLibraryComplexity extends AbstractOpticalDuplicateFinderCommandLineProgram {
     static final String USAGE_SUMMARY = "Estimates the numbers of unique molecules in a sequencing library.  ";
     static final String USAGE_DETAILS = "<p>This tool outputs quality metrics for a sequencing library preparation." +
@@ -113,45 +115,45 @@ public class EstimateLibraryComplexity extends AbstractOpticalDuplicateFinderCom
             "Please see the documentation for the companion " +
             "<a href='https://broadinstitute.github.io/picard/command-line-overview.html#MarkDuplicates'>MarkDuplicates</a> tool." +
             "<hr />";
-    @Option(shortName = StandardOptionDefinitions.INPUT_SHORT_NAME, doc = "One or more files to combine and " +
+    @Argument(shortName = StandardOptionDefinitions.INPUT_SHORT_NAME, doc = "One or more files to combine and " +
             "estimate library complexity from. Reads can be mapped or unmapped.")
     public List<File> INPUT;
 
-    @Option(shortName = StandardOptionDefinitions.OUTPUT_SHORT_NAME,
+    @Argument(shortName = StandardOptionDefinitions.OUTPUT_SHORT_NAME,
             doc = "Output file to writes per-library metrics to.")
     public File OUTPUT;
 
-    @Option(doc = "The minimum number of bases at the starts of reads that must be identical for reads to " +
+    @Argument(doc = "The minimum number of bases at the starts of reads that must be identical for reads to " +
             "be grouped together for duplicate detection.  In effect total_reads / 4^max_id_bases reads will " +
             "be compared at a time, so lower numbers will produce more accurate results but consume " +
             "exponentially more memory and CPU.")
     public int MIN_IDENTICAL_BASES = 5;
 
-    @Option(doc = "The maximum rate of differences between two reads to call them identical.")
+    @Argument(doc = "The maximum rate of differences between two reads to call them identical.")
     public double MAX_DIFF_RATE = 0.03;
 
-    @Option(doc = "The minimum mean quality of the bases in a read pair for the read to be analyzed. Reads with " +
+    @Argument(doc = "The minimum mean quality of the bases in a read pair for the read to be analyzed. Reads with " +
             "lower average quality are filtered out and not considered in any calculations.")
     public int MIN_MEAN_QUALITY = 20;
 
-    @Option(doc = "Do not process self-similar groups that are this many times over the mean expected group size. " +
+    @Argument(doc = "Do not process self-similar groups that are this many times over the mean expected group size. " +
             "I.e. if the input contains 10m read pairs and MIN_IDENTICAL_BASES is set to 5, then the mean expected " +
             "group size would be approximately 10 reads.")
     public int MAX_GROUP_RATIO = 500;
 
-    @Option(doc = "Barcode SAM tag (ex. BC for 10X Genomics)", optional = true)
+    @Argument(doc = "Barcode SAM tag (ex. BC for 10X Genomics)", optional = true)
     public String BARCODE_TAG = null;
 
-    @Option(doc = "Read one barcode SAM tag (ex. BX for 10X Genomics)", optional = true)
+    @Argument(doc = "Read one barcode SAM tag (ex. BX for 10X Genomics)", optional = true)
     public String READ_ONE_BARCODE_TAG = null;
 
-    @Option(doc = "Read two barcode SAM tag (ex. BX for 10X Genomics)", optional = true)
+    @Argument(doc = "Read two barcode SAM tag (ex. BX for 10X Genomics)", optional = true)
     public String READ_TWO_BARCODE_TAG = null;
 
-    @Option(doc = "The maximum number of bases to consider when comparing reads (0 means no maximum).", optional = true)
+    @Argument(doc = "The maximum number of bases to consider when comparing reads (0 means no maximum).", optional = true)
     public int MAX_READ_LENGTH = 0;
 
-    @Option(doc = "Minimum number group count.  On a per-library basis, we count the number of groups of duplicates " +
+    @Argument(doc = "Minimum number group count.  On a per-library basis, we count the number of groups of duplicates " +
             "that have a particular size.  Omit from consideration any count that is less than this value.  For " +
             "example, if we see only one group of duplicates with size 500, we omit it from the metric calculations if " +
             "MIN_GROUP_COUNT is set to two.  Setting this to two may help remove technical artifacts from the library " +
@@ -190,9 +192,6 @@ public class EstimateLibraryComplexity extends AbstractOpticalDuplicateFinderCom
         int[] hashes1;
         int[] hashes2;
 
-        // Possible candidates for this PairedReadSequence
-        Set<PairedReadSequence> dupCandidates;
-
         public static int getSizeInBytes() {
             // rough guess at memory footprint, summary size of all fields
             return 16 + 4 + (2 * 4) + 1 + 2 * (24 + 8 + NUMBER_BASES_IN_READ) + 2 + (2 * (24 + 8)) + 8 + 4;
@@ -210,26 +209,31 @@ public class EstimateLibraryComplexity extends AbstractOpticalDuplicateFinderCom
             return new PairedReadCodec();
         }
 
-        void initHashes(int maxReadLength, int hashLength, int skippedBases) {
-            dupCandidates = new HashSet<>();
-            hashes1 = getHashes(read1, maxReadLength, hashLength, skippedBases);
-            hashes2 = getHashes(read2, maxReadLength, hashLength, skippedBases);
+        void initHashes(int numberOfHashes, int skippedBases, int minReadLength) {
+            hashes1 = getHashes(read1, numberOfHashes, skippedBases, minReadLength);
+            hashes2 = getHashes(read2, numberOfHashes, skippedBases, minReadLength);
         }
 
-        // Split read by (MAX_DIFF_RATE * read.length + 1) parts and hash each part
-        private int[] getHashes(byte[] read, int maxReadLength, int hashLength, int skippedBases) {
-            int maxLengthWithoutHead = maxReadLength - skippedBases;
-            int hashNum = (Math.min(read.length - skippedBases, maxLengthWithoutHead)) /
-                    hashLength;
-            int[] hashValues = new int[hashNum];
-            for (int i = 0; i < hashNum; ++i) {
-                int st = skippedBases + i * hashLength;
-                int end = st + hashLength;
-
-                // use custom hash to avoid using System.arraycopy
+        // Split read by numberOfHashes parts and hash each part
+        // For instance:
+        //        0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19
+        // read = A C G T A C G T A C G  T  A  C  G  T  A  C  G  T
+        // numberOfHashes = 5
+        // skippedBases = 1
+        // minReadLength = 15
+        // So, method returns hashValues with 5 hash value
+        // first value calculated from read[1], read[6], read[11]
+        // second value calculated from read[2], read[7], read[12]
+        // etc.
+        // chars from 16 to 19 position is a tail, see compareTails() in ElcHashBasedDuplicatesFinder
+        private int[] getHashes(byte[] read, int numberOfHashes, int skippedBases, int minReadLength) {
+            final int[] hashValues = new int[numberOfHashes];
+            for (int i = 0; i < numberOfHashes; ++i) {
                 hashValues[i] = 1;
-                for (int j = st; j < end; ++j) {
-                    hashValues[i] = 31 * hashValues[i] + read[j];
+                int position = skippedBases + i;
+                while (position < minReadLength) {
+                    hashValues[i] = 31 * hashValues[i] + read[position];
+                    position += numberOfHashes;
                 }
             }
             return hashValues;
@@ -413,11 +417,6 @@ public class EstimateLibraryComplexity extends AbstractOpticalDuplicateFinderCom
         return getReadBarcodeValue(record, READ_TWO_BARCODE_TAG);
     }
 
-    /** Stock main method. */
-    public static void main(final String[] args) {
-        new EstimateLibraryComplexity().instanceMainWithExit(args);
-    }
-
     public EstimateLibraryComplexity() {
         final int sizeInBytes;
         if (null != BARCODE_TAG || null != READ_ONE_BARCODE_TAG || null != READ_TWO_BARCODE_TAG) {
