@@ -54,7 +54,7 @@ import java.util.Set;
 
 /**
  * Abstract class that holds parameters and methods common to classes that perform duplicate
- * detection and/or marking within SAM/BAM files.
+ * detection and/or marking within SAM/BAM/CRAM files.
  *
  * @author Nils Homer
  */
@@ -64,7 +64,7 @@ public abstract class AbstractMarkDuplicatesCommandLineProgram extends AbstractO
     protected final PGTagArgumentCollection pgTagArgumentCollection = new PGTagArgumentCollection();
 
     @Argument(shortName = StandardOptionDefinitions.INPUT_SHORT_NAME,
-            doc = "One or more input SAM or BAM files to analyze. Must be coordinate sorted.")
+            doc = "One or more input SAM, BAM or CRAM files to analyze. Must be coordinate sorted.")
     public List<String> INPUT;
 
     @Argument(shortName = StandardOptionDefinitions.OUTPUT_SHORT_NAME,
@@ -258,11 +258,12 @@ public abstract class AbstractMarkDuplicatesCommandLineProgram extends AbstractO
         final List<SamReader> readers = new ArrayList<>(INPUT.size());
 
         for (final String input : INPUT) {
-            SamReaderFactory readerFactory = SamReaderFactory.makeDefault().referenceSequence(REFERENCE_SEQUENCE);
-            SamReader reader = eagerlyDecode ? readerFactory.enable(SamReaderFactory.Option.EAGERLY_DECODE).open(SamInputResource.of(input)) :
-                    readerFactory.open(SamInputResource.of(input));
+            final SamReaderFactory readerFactory = SamReaderFactory.makeDefault();
+            if (eagerlyDecode) {
+                readerFactory.enable(SamReaderFactory.Option.EAGERLY_DECODE);
+            }
+            final SamReader reader = readerFactory.referenceSequence(REFERENCE_SEQUENCE).open(SamInputResource.of(input));
             final SAMFileHeader header = reader.getFileHeader();
-
             headers.add(header);
             readers.add(reader);
         }
