@@ -30,14 +30,28 @@ import htsjdk.samtools.ValidationStringency;
 import htsjdk.samtools.liftover.LiftOver;
 import htsjdk.samtools.reference.ReferenceSequence;
 import htsjdk.samtools.reference.ReferenceSequenceFileWalker;
-import htsjdk.samtools.util.*;
+import htsjdk.samtools.util.CloserUtil;
+import htsjdk.samtools.util.CollectionUtil;
+import htsjdk.samtools.util.IOUtil;
+import htsjdk.samtools.util.Interval;
+import htsjdk.samtools.util.Log;
+import htsjdk.samtools.util.ProgressLogger;
+import htsjdk.samtools.util.SortingCollection;
+import htsjdk.samtools.util.StringUtil;
 import htsjdk.variant.variantcontext.Allele;
 import htsjdk.variant.variantcontext.VariantContext;
 import htsjdk.variant.variantcontext.VariantContextBuilder;
 import htsjdk.variant.variantcontext.writer.Options;
 import htsjdk.variant.variantcontext.writer.VariantContextWriter;
 import htsjdk.variant.variantcontext.writer.VariantContextWriterBuilder;
-import htsjdk.variant.vcf.*;
+import htsjdk.variant.vcf.VCFFileReader;
+import htsjdk.variant.vcf.VCFFilterHeaderLine;
+import htsjdk.variant.vcf.VCFHeader;
+import htsjdk.variant.vcf.VCFHeaderLine;
+import htsjdk.variant.vcf.VCFHeaderLineCount;
+import htsjdk.variant.vcf.VCFHeaderLineType;
+import htsjdk.variant.vcf.VCFInfoHeaderLine;
+import htsjdk.variant.vcf.VCFRecordCodec;
 import org.broadinstitute.barclay.argparser.Argument;
 import org.broadinstitute.barclay.argparser.CommandLineProgramProperties;
 import org.broadinstitute.barclay.help.DocumentedFeature;
@@ -50,7 +64,15 @@ import picard.util.LiftoverUtils;
 import java.io.File;
 import java.text.DecimalFormat;
 import java.text.NumberFormat;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.LinkedHashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.TreeMap;
+import java.util.TreeSet;
 import java.util.stream.Collectors;
 
 /**
@@ -181,6 +203,9 @@ public class LiftoverVcf extends CommandLineProgram {
     @Argument(doc = "INFO field annotations that should be deleted when swapping reference with variant alleles.", optional = true)
     public Collection<String> TAGS_TO_DROP = new ArrayList<>(LiftoverUtils.DEFAULT_TAGS_TO_DROP);
 
+    @Argument(doc = "Output VCF file will be written on the fly but it won't be sorted and indexed.", optional = true)
+    public boolean DISABLE_SORT = false;
+
     // When a contig used in the chain is not in the reference, exit with this value instead of 0.
     public static int EXIT_CODE_WHEN_CONTIG_NOT_IN_REFERENCE = 1;
 
@@ -249,14 +274,17 @@ public class LiftoverVcf extends CommandLineProgram {
             new VCFInfoHeaderLine(ORIGINAL_ALLELES, VCFHeaderLineCount.R, VCFHeaderLineType.String, "A list of the original alleles (including REF) of the variant prior to liftover.  If the alleles were not changed during liftover, this attribute will be omitted.")
     );
 
-    private VariantContextWriter rejects;
+    private VariantContextWriter rejectedRecords;
+    /** the output VariantContextWriter */
+    private VariantContextWriter acceptedRecords;
     private final Log log = Log.getInstance(LiftoverVcf.class);
+    /** the Variant sorter, may be null if DISABLE_SORT = true */
     private SortingCollection<VariantContext> sorter;
 
     private long failedLiftover = 0, failedAlleleCheck = 0, totalTrackedAsSwapRefAlt = 0;
-    private Map<String, Long> rejectsByContig = new TreeMap<>();
-    private Map<String, Long> liftedByDestContig = new TreeMap<>();
-    private Map<String, Long> liftedBySourceContig = new TreeMap<>();
+    private final Map<String, Long> rejectsByContig = new TreeMap<>();
+    private final Map<String, Long> liftedByDestContig = new TreeMap<>();
+    private final Map<String, Long> liftedBySourceContig = new TreeMap<>();
 
     @Override
     protected ReferenceArgumentCollection makeReferenceArgumentCollection() {
@@ -281,6 +309,11 @@ public class LiftoverVcf extends CommandLineProgram {
         IOUtil.assertFileIsWritable(OUTPUT);
         IOUtil.assertFileIsWritable(REJECT);
 
+        
+        if (CREATE_INDEX && DISABLE_SORT) {
+            log.error("CREATE_INDEX=true and DISABLE_SORT=true are mutually exclusive.");
+            return 1;
+        }
         ////////////////////////////////////////////////////////////////////////
         // Setup the inputs
         ////////////////////////////////////////////////////////////////////////
@@ -306,7 +339,14 @@ public class LiftoverVcf extends CommandLineProgram {
         // Setup the outputs
         ////////////////////////////////////////////////////////////////////////
         final VCFHeader inHeader = in.getFileHeader();
-        final VCFHeader outHeader = new VCFHeader(inHeader);
+        // build VCF header, remove the old '##reference=file://...'
+        final VCFHeader outHeader = new VCFHeader(
+            inHeader.getMetaDataInInputOrder()
+                .stream()
+                .filter(M->!M.getKey().equals("reference"))
+                .collect(Collectors.toCollection(LinkedHashSet::new)),
+            inHeader.getSampleNamesInOrder()
+            );
         outHeader.setSequenceDictionary(walker.getSequenceDictionary());
         if (WRITE_ORIGINAL_POSITION) {
             for (final VCFInfoHeaderLine line : ATTRS) outHeader.addMetaDataLine(line);
@@ -320,14 +360,18 @@ public class LiftoverVcf extends CommandLineProgram {
         outHeader.addMetaDataLine(new VCFInfoHeaderLine(LiftoverUtils.REV_COMPED_ALLELES, 0, VCFHeaderLineType.Flag,
                 "The REF and the ALT alleles have been reverse complemented in liftover since the mapping from the " +
                         "previous reference to the current one was on the negative strand."));
+        outHeader.addMetaDataLine(new VCFHeaderLine("reference", REFERENCE_SEQUENCE.toURI().toString()));
+        
+        this.acceptedRecords = new VariantContextWriterBuilder()
+            .modifyOption(Options.ALLOW_MISSING_FIELDS_IN_HEADER, ALLOW_MISSING_FIELDS_IN_HEADER)
+            .modifyOption(Options.INDEX_ON_THE_FLY,!DISABLE_SORT)
+            .setOutputFile(OUTPUT)
+            .setReferenceDictionary(walker.getSequenceDictionary())
+            .build();
+        
+        this.acceptedRecords.writeHeader(outHeader);
 
-        final VariantContextWriter out = new VariantContextWriterBuilder()
-                .setOption(Options.INDEX_ON_THE_FLY)
-                .modifyOption(Options.ALLOW_MISSING_FIELDS_IN_HEADER, ALLOW_MISSING_FIELDS_IN_HEADER)
-                .setOutputFile(OUTPUT).setReferenceDictionary(walker.getSequenceDictionary()).build();
-        out.writeHeader(outHeader);
-
-        rejects = new VariantContextWriterBuilder().setOutputFile(REJECT)
+        rejectedRecords = new VariantContextWriterBuilder().setOutputFile(REJECT)
                 .unsetOption(Options.INDEX_ON_THE_FLY)
                 .modifyOption(Options.ALLOW_MISSING_FIELDS_IN_HEADER, ALLOW_MISSING_FIELDS_IN_HEADER)
                 .build();
@@ -339,20 +383,28 @@ public class LiftoverVcf extends CommandLineProgram {
         rejectHeader.addMetaDataLine(new VCFInfoHeaderLine(ATTEMPTED_LOCUS, 1, VCFHeaderLineType.String, "The locus of the variant in the TARGET prior to failing due to reference allele mismatching to the target reference."));
         rejectHeader.addMetaDataLine(new VCFInfoHeaderLine(ATTEMPTED_ALLELES, 1, VCFHeaderLineType.String, "The alleles of the variant in the TARGET prior to failing due to reference allele mismatching to the target reference."));
 
-        rejects.writeHeader(rejectHeader);
+        rejectedRecords.writeHeader(rejectHeader);
 
         ////////////////////////////////////////////////////////////////////////
         // Read the input VCF, lift the records over and write to the sorting
         // collection.
         ////////////////////////////////////////////////////////////////////////
         long total = 0;
-        log.info("Lifting variants over and sorting (not yet writing the output file.)");
-
-        sorter = SortingCollection.newInstance(VariantContext.class,
-                new VCFRecordCodec(outHeader, ALLOW_MISSING_FIELDS_IN_HEADER || VALIDATION_STRINGENCY != ValidationStringency.STRICT),
-                outHeader.getVCFRecordComparator(),
-                MAX_RECORDS_IN_RAM,
-                TMP_DIR);
+        
+        if (DISABLE_SORT) {
+            log.info("Lifting variants over and writing the output file. Variants will not be sorted.");
+            
+            sorter = null;
+            }
+        else {
+            log.info("Lifting variants over and sorting (not yet writing the output file.)");
+    
+            sorter = SortingCollection.newInstance(VariantContext.class,
+                    new VCFRecordCodec(outHeader, ALLOW_MISSING_FIELDS_IN_HEADER || VALIDATION_STRINGENCY != ValidationStringency.STRICT),
+                    outHeader.getVCFRecordComparator(),
+                    MAX_RECORDS_IN_RAM,
+                    TMP_DIR);
+            }
 
         ProgressLogger progress = new ProgressLogger(log, 1000000, "read");
 
@@ -438,34 +490,37 @@ public class LiftoverVcf extends CommandLineProgram {
             log.warn(totalTrackedAsSwapRefAlt, " variants with a swapped REF/ALT were identified, but were not recovered.  See RECOVER_SWAPPED_REF_ALT and associated caveats.");
         }
 
-        rejects.close();
+        rejectedRecords.close();
         in.close();
 
-        ////////////////////////////////////////////////////////////////////////
-        // Write the sorted outputs to the final output file
-        ////////////////////////////////////////////////////////////////////////
-        sorter.doneAdding();
-        progress = new ProgressLogger(log, 1000000, "written");
-        log.info("Writing out sorted records to final VCF.");
-
-        for (final VariantContext ctx : sorter) {
-            out.add(ctx);
-            progress.record(ctx.getContig(), ctx.getStart());
+        if (!DISABLE_SORT) { 
+            ////////////////////////////////////////////////////////////////////////
+            // Write the sorted outputs to the final output file
+            ////////////////////////////////////////////////////////////////////////
+            sorter.doneAdding();
+            progress = new ProgressLogger(log, 1000000, "written");
+            log.info("Writing out sorted records to final VCF.");
+    
+            for (final VariantContext ctx : sorter) {
+                this.acceptedRecords.add(ctx);
+                progress.record(ctx.getContig(), ctx.getStart());
+            }
+    
+            sorter.cleanup();
         }
-        out.close();
-
-        sorter.cleanup();
 
+        this.acceptedRecords.close();
+        
         return 0;
     }
 
     private void rejectVariant(final VariantContext ctx, final String reason) {
-        rejects.add(new VariantContextBuilder(ctx).filter(reason).make());
+        rejectedRecords.add(new VariantContextBuilder(ctx).filter(reason).make());
         failedLiftover++;
         trackLiftedVariantContig(rejectsByContig, ctx.getContig());
     }
 
-    private void trackLiftedVariantContig(Map<String, Long> map, String contig) {
+    private void trackLiftedVariantContig(final Map<String, Long> map, final String contig) {
         Long val = map.get(contig);
         if (val == null) {
             val = 0L;
@@ -477,7 +532,11 @@ public class LiftoverVcf extends CommandLineProgram {
     private void addAndTrack(final VariantContext toAdd, final VariantContext source) {
         trackLiftedVariantContig(liftedBySourceContig, source.getContig());
         trackLiftedVariantContig(liftedByDestContig, toAdd.getContig());
-        sorter.add(toAdd);
+        if (!DISABLE_SORT) { //we're sorting the variants
+            sorter.add(toAdd);
+        } else {
+            this.acceptedRecords.add(toAdd);
+        }
     }
 
     /**
@@ -493,31 +552,28 @@ public class LiftoverVcf extends CommandLineProgram {
         }
 
         // Check that the reference allele still agrees with the reference sequence
-        boolean mismatchesReference = false;
-        for (final Allele allele : vc.getAlleles()) {
-            if (allele.isReference()) {
-                final byte[] ref = refSeq.getBases();
-                final String refString = StringUtil.bytesToString(ref, vc.getStart() - 1, vc.getEnd() - vc.getStart() + 1);
+        final boolean mismatchesReference;
+        final Allele allele = vc.getReference();
+        final byte[] ref = refSeq.getBases();
+        final String refString = StringUtil.bytesToString(ref, vc.getStart() - 1, vc.getEnd() - vc.getStart() + 1);
 
-                if (!refString.equalsIgnoreCase(allele.getBaseString())) {
-                    // consider that the ref and the alt may have been swapped in a simple biallelic SNP
-                    if (vc.isBiallelic() && vc.isSNP() && refString.equalsIgnoreCase(vc.getAlternateAllele(0).getBaseString())) {
-                        if (RECOVER_SWAPPED_REF_ALT) {
-                            totalTrackedAsSwapRefAlt++;
-                            addAndTrack(LiftoverUtils.swapRefAlt(vc, TAGS_TO_REVERSE, TAGS_TO_DROP), source);
-                            return;
-                        } else {
-                            totalTrackedAsSwapRefAlt++;
-                        }
-                    }
-                    mismatchesReference = true;
+        if (!refString.equalsIgnoreCase(allele.getBaseString())) {
+            // consider that the ref and the alt may have been swapped in a simple biallelic SNP
+            if (vc.isBiallelic() && vc.isSNP() && refString.equalsIgnoreCase(vc.getAlternateAllele(0).getBaseString())) {
+                totalTrackedAsSwapRefAlt++;
+                if (RECOVER_SWAPPED_REF_ALT) {
+                    addAndTrack(LiftoverUtils.swapRefAlt(vc, TAGS_TO_REVERSE, TAGS_TO_DROP), source);
+                    return;
                 }
-                break;
             }
+            mismatchesReference = true;
+        } else {
+            mismatchesReference = false;
         }
 
+
         if (mismatchesReference) {
-            rejects.add(new VariantContextBuilder(source)
+            rejectedRecords.add(new VariantContextBuilder(source)
                     .filter(FILTER_MISMATCHING_REF_ALLELE)
                     .attribute(ATTEMPTED_LOCUS, String.format("%s:%d-%d", vc.getContig(), vc.getStart(), vc.getEnd()))
                     .attribute(ATTEMPTED_ALLELES, vc.getReference().toString() + "->" + String.join(",", vc.getAlternateAlleles().stream().map(Allele::toString).collect(Collectors.toList())))
