@@ -25,25 +25,23 @@ package picard.illumina;
 
 import htsjdk.samtools.metrics.MetricsFile;
 import htsjdk.samtools.util.IOUtil;
+import org.apache.commons.io.FileUtils;
 import org.testng.Assert;
 import org.testng.annotations.AfterTest;
 import org.testng.annotations.BeforeTest;
 import org.testng.annotations.DataProvider;
 import org.testng.annotations.Test;
 import picard.cmdline.CommandLineProgramTest;
-import picard.illumina.parser.BaseIlluminaDataProvider;
-import picard.illumina.parser.ClusterData;
-import picard.illumina.parser.IlluminaDataProviderFactory;
-import picard.illumina.parser.IlluminaDataType;
-import picard.illumina.parser.ReadStructure;
+import picard.illumina.parser.*;
 import picard.illumina.parser.readers.BclQualityEvaluationStrategy;
 import picard.util.BasicInputParser;
+import picard.util.IlluminaUtil;
 
 import java.io.File;
 import java.io.FileReader;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
+import java.util.*;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.stream.Collectors;
 
 /**
  * @author alecw@broadinstitute.org
@@ -85,10 +83,12 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         Assert.assertTrue(basecallsDir.delete());
         Assert.assertTrue(basecallsDir.mkdir());
         IOUtil.copyDirectoryTree(SINGLE_DATA_DIR, basecallsDir);
+
         dual = File.createTempFile("eib_dual", ".tmp");
         Assert.assertTrue(dual.delete());
         Assert.assertTrue(dual.mkdir());
         IOUtil.copyDirectoryTree(DUAL_DATA_DIR, dual);
+
         qual = File.createTempFile("eib_qual", ".tmp");
         Assert.assertTrue(qual.delete());
         Assert.assertTrue(qual.mkdir());
@@ -103,6 +103,14 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         Assert.assertTrue(cbcl.delete());
         Assert.assertTrue(cbcl.mkdir());
         IOUtil.copyDirectoryTree(CBCL_DATA_DIR, cbcl);
+        // For the cbcl test, we are deleting the '*barcode.txt.gz' files that exist in the test Basecalls directory
+        // This is to prevent the error conditon that was briefly introduced which expected to find such files in that
+        // directory before EIB was run on it.
+        final File basecallsDir = new File(cbcl, "BaseCalls");
+        Collection<File> barcodeFiles = FileUtils.listFiles(basecallsDir, new String[]{"txt.gz"}, false);
+        for (final File barcodeFile : barcodeFiles) {
+            Assert.assertTrue(barcodeFile.delete());
+        }
     }
 
     @AfterTest
@@ -111,47 +119,48 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         IOUtil.deleteDirectoryTree(dual);
         IOUtil.deleteDirectoryTree(qual);
         IOUtil.deleteDirectoryTree(noSymlink);
+        IOUtil.deleteDirectoryTree(cbcl);
     }
 
     @Test
     public void testSingleEndWithBarcodeAtStart() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "8B25T");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "8B25T");
         Assert.assertEquals(metricsFile.getMetrics().get(11).PERFECT_MATCHES, 1);
     }
 
     @Test
     public void testSingleEndWithBarcodeAtStartAndMolecularIndicies() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "8B4M21T");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "8B4M21T");
         Assert.assertEquals(metricsFile.getMetrics().get(11).PERFECT_MATCHES, 1);
     }
 
     @Test
     public void testSingleEndWithBarcodeAtEnd() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "25T8B");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "25T8B");
         Assert.assertEquals(metricsFile.getMetrics().get(0).PERFECT_MATCHES, 5);
     }
 
     @Test
     public void testSingleEndWithBarcodeAtEndAndMolecularIndicies() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "4M21T8B");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "4M21T8B");
         Assert.assertEquals(metricsFile.getMetrics().get(0).PERFECT_MATCHES, 5);
     }
 
     @Test
     public void testPairedEndWithBarcodeOnFirstEnd() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "25T8B25T");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "25T8B25T");
         Assert.assertEquals(metricsFile.getMetrics().get(0).PERFECT_MATCHES, 5);
     }
 
     @Test
     public void testPairedEndWithBarcodeAndMolecularIndicies() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "4M21T8B21T4M");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "4M21T8B21T4M");
         Assert.assertEquals(metricsFile.getMetrics().get(0).PERFECT_MATCHES, 5);
     }
 
     @Test
     public void testPairedEndWithBarcodeOnSecondEnd() throws Exception {
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(1, "25T25T8B");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(1, "25T25T8B");
         Assert.assertEquals(metricsFile.getMetrics().get(12).PERFECT_MATCHES, 1);
     }
 
@@ -196,12 +205,12 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
     public void testBarcodeMatching() throws Exception {
         final int lane = 1;
         final int barcodePosition = 26;
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> metricsFile = runIt(lane, "25T8B25T");
+        final MetricsFile<BarcodeMetric, Integer> metricsFile = runIt(lane, "25T8B25T");
 
-        ExtractIlluminaBarcodes.BarcodeMetric metricOne = null;
-        ExtractIlluminaBarcodes.BarcodeMetric metricTwo = null;
-        ExtractIlluminaBarcodes.BarcodeMetric metricNoMatch = null;
-        for (final ExtractIlluminaBarcodes.BarcodeMetric metric : metricsFile.getMetrics()) {
+        BarcodeMetric metricOne = null;
+        BarcodeMetric metricTwo = null;
+        BarcodeMetric metricNoMatch = null;
+        for (final BarcodeMetric metric : metricsFile.getMetrics()) {
             if (metric.BARCODE.equals(BARCODES[0])) {
                 metricOne = metric;
             } else if (metric.BARCODE.equals(BARCODES[2])) {
@@ -248,7 +257,7 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         final ReadStructure rs = new ReadStructure("25T8B25T");
         final IlluminaDataProviderFactory factory = new IlluminaDataProviderFactory(basecallsDir, lane, rs,
                 new BclQualityEvaluationStrategy(BclQualityEvaluationStrategy.ILLUMINA_ALLEGED_MINIMUM_QUALITY),
-                IlluminaDataType.BaseCalls, IlluminaDataType.QualityScores, IlluminaDataType.Barcodes);
+                new HashSet<>(Arrays.asList(IlluminaDataType.BaseCalls, IlluminaDataType.QualityScores, IlluminaDataType.Barcodes)));
         testParsing(factory, rs, metricOne, barcodePosition);
     }
 
@@ -266,7 +275,7 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         };
 
         Assert.assertEquals(runPicardCommandLine(args), 0);
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> result = new MetricsFile<>();
+        final MetricsFile<BarcodeMetric, Integer> result = new MetricsFile<>();
         result.read(new FileReader(metricsFile));
         Assert.assertEquals(result.getMetrics().get(0).PERFECT_MATCHES, 1, "Got wrong number of perfect matches");
         Assert.assertEquals(result.getMetrics().get(0).ONE_MISMATCH_MATCHES, 0, "Got wrong number of one-mismatch matches");
@@ -283,10 +292,11 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
                 "METRICS_FILE=" + metricsFile.getPath(),
                 "READ_STRUCTURE=" + "151T8B8B151T",
                 "BARCODE=" + "CACCTAGTACTCGAGT"
+
         };
 
         Assert.assertEquals(runPicardCommandLine(args), 0);
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> result = new MetricsFile<>();
+        final MetricsFile<BarcodeMetric, Integer> result = new MetricsFile<>();
         result.read(new FileReader(metricsFile));
         Assert.assertEquals(result.getMetrics().get(0).PERFECT_MATCHES, 1, "Got wrong number of perfect matches");
         Assert.assertEquals(result.getMetrics().get(0).ONE_MISMATCH_MATCHES, 0, "Got wrong number of one-mismatch matches");
@@ -313,7 +323,7 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         };
 
         Assert.assertEquals(runPicardCommandLine(args), 0);
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> result = new MetricsFile<>();
+        final MetricsFile<BarcodeMetric, Integer> result = new MetricsFile<>();
         result.read(new FileReader(metricsFile));
         Assert.assertEquals(result.getMetrics().get(0).PERFECT_MATCHES, perfectMatches, "Got wrong number of perfect matches for test: '" + testName + "'");
         Assert.assertEquals(result.getMetrics().get(0).ONE_MISMATCH_MATCHES, oneMismatch, "Got wrong number of one-mismatch matches for test: '" + testName + "'");
@@ -341,13 +351,13 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         };
 
         Assert.assertEquals(runPicardCommandLine(args), 0);
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> result = new MetricsFile<>();
+        final MetricsFile<BarcodeMetric, Integer> result = new MetricsFile<>();
         result.read(new FileReader(metricsFile));
         Assert.assertEquals(result.getMetrics().get(0).PERFECT_MATCHES, 2, "Got wrong number of perfect matches");
         Assert.assertEquals(result.getMetrics().get(0).ONE_MISMATCH_MATCHES, 0, "Got wrong number of one-mismatch matches");
     }
 
-    private void testParsing(final IlluminaDataProviderFactory factory, final ReadStructure readStructure, final ExtractIlluminaBarcodes.BarcodeMetric metricACAGTG, final int barcodePosition) {
+    private void testParsing(final IlluminaDataProviderFactory factory, final ReadStructure readStructure, final BarcodeMetric metricACAGTG, final int barcodePosition) {
 
         int numReads = 0;
 
@@ -366,7 +376,7 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         dataProvider.close();
     }
 
-    private MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> runIt(final int lane, final String readStructure)
+    private MetricsFile<BarcodeMetric, Integer> runIt(final int lane, final String readStructure)
             throws Exception {
         final File metricsFile = File.createTempFile("eib.", ".metrics");
         metricsFile.deleteOnExit();
@@ -383,12 +393,55 @@ public class ExtractIlluminaBarcodesTest extends CommandLineProgramTest {
         return runIt(args, metricsFile);
     }
 
-    private MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> runIt(final List<String> args, final File metricsFile) throws Exception {
+    private MetricsFile<BarcodeMetric, Integer> runIt(final List<String> args, final File metricsFile) throws Exception {
         // Generate _barcode.txt files and metrics file.
         Assert.assertEquals(runPicardCommandLine(args), 0);
 
-        final MetricsFile<ExtractIlluminaBarcodes.BarcodeMetric, Integer> retval = new MetricsFile<>();
+        final MetricsFile<BarcodeMetric, Integer> retval = new MetricsFile<>();
         retval.read(new FileReader(metricsFile));
         return retval;
     }
+
+    @DataProvider
+    Object[][] testDeltaData(){
+        return new Object[][]{
+                new Object[] {new String[]{"ACCAAC", "GAATTC"}, new String [] {"!AAAAA","!AAAAA"}, 2, 5},
+                new Object[] {new String[]{"CTACGC", "TGTCGT"}, new String [] {"!AAAAA","!AAAAA"}, 5, 5},
+                new Object[] {new String[]{"AGGTCG", "AATTGT"}, new String [] {"AAAAAA","AAAAAA"}, 0, 5},
+        };
+    }
+
+    @Test(dataProvider = "testDeltaData")
+    void testDelta(final String[] barcodeRead, final String[] barcodeQuality, final int expectedMismatches, final int expectedSecondMismatches) {
+
+        final List<String[]> barcodes = Arrays.asList(
+                new String[]{"CTGTGG", "GGCTAG"},
+                new String[]{"AGGTCG", "AATTGT"},
+                new String[]{"ACCAAC", "GTATTG"}
+                );
+        final Map<String, BarcodeMetric> barcodeMetrics = barcodes.stream()
+                .collect(Collectors.toMap(
+                        s -> s[0] + s[1],
+                        s -> new BarcodeMetric("dummy_name","dummy_library", s[0] + s[1], s)));
+
+        final byte[][] reads     = new byte[][]{barcodeRead[0].getBytes(), barcodeRead[1].getBytes()};
+        final byte[][] qualities = new byte[][]{barcodeQuality[0].getBytes(), barcodeQuality[1].getBytes()};
+
+        BarcodeMetric noMatchMetric = new BarcodeMetric(null, null, "NNNNNNNNNNNN", new String[]{"NNNNNN", "NNNNNN"});
+
+        final BarcodeExtractor barcodeExtractor = new BarcodeExtractor(
+                barcodeMetrics,
+                noMatchMetric,
+                new ReadStructure("10T6B6B10T"),
+                2,
+                2,
+                2,
+                20,
+                DistanceMetric.HAMMING);
+
+        final BarcodeExtractor.BarcodeMatch match = barcodeExtractor.calculateBarcodeMatch(reads, qualities, false);
+
+        Assert.assertEquals(match.getMismatches(), expectedMismatches);
+        Assert.assertEquals(match.getMismatchesToSecondBest(), expectedSecondMismatches);
+    }
 }
