@@ -1,19 +1,16 @@
 package picard.sam.testers;
 
 import htsjdk.samtools.DuplicateScoringStrategy.ScoringStrategy;
-import htsjdk.samtools.SAMFileHeader;
-import htsjdk.samtools.SAMFileWriter;
-import htsjdk.samtools.SAMFileWriterFactory;
-import htsjdk.samtools.SAMRecord;
-import htsjdk.samtools.SAMRecordSetBuilder;
-import htsjdk.samtools.SamReader;
-import htsjdk.samtools.util.IOUtil;
+import htsjdk.samtools.*;
+import htsjdk.samtools.reference.ReferenceSequenceFileFactory;
 import htsjdk.samtools.util.CloseableIterator;
+import htsjdk.samtools.util.IOUtil;
 import org.testng.Assert;
 import picard.cmdline.CommandLineProgramTest;
 
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Path;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -30,9 +27,11 @@ public abstract class SamFileTester extends CommandLineProgramTest {
     private File output;
     private int readNameCounter = 0;
     protected boolean noMateCigars = false;
-    private boolean deleteOnExit = true;
+    final private boolean deleteOnExit;
     private final ArrayList<String> args = new ArrayList<>();
 
+    protected Map<SAMFileHeader, Path> fastaFiles = new HashMap<>();
+
     public SamFileTester(final int readLength, final boolean deleteOnExit, final int defaultChromosomeLength, final ScoringStrategy duplicateScoringStrategy, final SAMFileHeader.SortOrder sortOrder, boolean recordsNeedSorting) {
         this.deleteOnExit = deleteOnExit;
         this.samRecordSetBuilder = new SAMRecordSetBuilder(recordsNeedSorting, sortOrder, true, defaultChromosomeLength, duplicateScoringStrategy);
@@ -83,7 +82,6 @@ public abstract class SamFileTester extends CommandLineProgramTest {
         this.output = output;
     }
 
-
     public void addArg(final String arg) {
         args.add(arg);
     }
@@ -125,7 +123,7 @@ public abstract class SamFileTester extends CommandLineProgramTest {
         }
         nameBuilder.append("-")
                 .append(record.getReadPairedFlag())
-                .append("-").append(record.getNotPrimaryAlignmentFlag())
+                .append("-").append(record.isSecondaryAlignment())
                 .append("-");
 
         if (record.getReadPairedFlag()) {
@@ -350,12 +348,25 @@ public abstract class SamFileTester extends CommandLineProgramTest {
      * Sets up the basic command line arguments for input and output and runs instanceMain.
      */
     public void runTest() {
+        runTest(".sam");
+    }
+
+
+    /**
+     * Sets up the basic command line arguments for input and output and runs instanceMain.
+     */
+    public void runTest(final String inputExtension) {
         try {
-            final File input = createInputFile();
+            final File input = createInputFile(inputExtension);
 
             output = new File(outputDir, "output.sam");
             args.add("INPUT=" + input.getAbsoluteFile());
             args.add("OUTPUT=" + output.getAbsoluteFile());
+            if (inputExtension.equals(".cram")) {
+                args.add("REFERENCE_SEQUENCE=" + fastaFiles.get(samRecordSetBuilder.getHeader()));
+            }
+
+            customPretestCallback();
             Assert.assertEquals(runPicardCommandLine(args), 0);
             test();
         } catch (IOException ex) {
@@ -364,12 +375,53 @@ public abstract class SamFileTester extends CommandLineProgramTest {
         }
     }
 
-    private File createInputFile() {
+    protected void customPretestCallback(){};
+
+    private File createInputFile(final String extension) throws IOException {
         // Create the input file
-        final File input = new File(outputDir, "input.sam");
-        final SAMFileWriter writer = new SAMFileWriterFactory().makeSAMOrBAMWriter(samRecordSetBuilder.getHeader(), true, input);
-        samRecordSetBuilder.getRecords().forEach(writer::addAlignment);
+        final File input = new File(outputDir, "input" + extension);
+
+        final SAMFileWriterFactory samFileWriterFactory = new SAMFileWriterFactory();
+
+        final SAMFileWriter writer;
+        if (extension.equals(".cram")) {
+            final Path fasta = fastaFiles.computeIfAbsent(samRecordSetBuilder.getHeader(), h -> {
+
+                final Path fastaDir = IOUtil.createTempDir("SamFileTester", "").toPath();
+                IOUtil.deleteOnExit(fastaDir);
+                final Path newFasta = fastaDir.resolve("input.fasta");
+                IOUtil.deleteOnExit(newFasta);
+                IOUtil.deleteOnExit(ReferenceSequenceFileFactory.getFastaIndexFileName(newFasta));
+                IOUtil.deleteOnExit(ReferenceSequenceFileFactory.getDefaultDictionaryForReferenceSequence(newFasta));
+
+                try {
+                    long sum = samRecordSetBuilder.getHeader()
+                            .getSequenceDictionary().getSequences().stream()
+                            .mapToLong(SAMSequenceRecord::getSequenceLength)
+                            .sum();
+                    Assert.assertFalse(sum >= 10_000_000,
+                            "Sequence dictionary is very large (total size " + sum + "). In a Cram test this could be a problem leading to writing lots" +
+                                    "of bases to disk. please modify the tester using 'ModifyTesterForCramTests'. " +
+                                    "For example look at testBulkFragmentsNoDuplicates in AbstractMarkDuplicatesCommandLineProgramTest");
+
+                    samRecordSetBuilder.writeRandomReference(newFasta);
+                } catch (IOException e) {
+                    e.printStackTrace();
+                    throw new RuntimeException("failed to create fasta file");
+                }
+                return newFasta;
+            });
+
+            writer = samFileWriterFactory.makeWriter(samRecordSetBuilder.getHeader(), true, input, fasta.toFile());
+        } else {
+            writer = samFileWriterFactory.makeWriter(samRecordSetBuilder.getHeader(), true, input, null);
+        }
+
+        for(final SAMRecord a : samRecordSetBuilder.getRecords()) {
+            writer.addAlignment(a);
+        }
         writer.close();
+
         return input;
     }
 
